@@ -5,3 +5,5 @@ class Config(msgspec.Struct):
     username: int
     password: int | None = None
     headless: bool = True
+    timeoutMs: int = 30000
+    saveTrace: bool = False
